Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Company ¶
type Company struct {
Symbol string
CompanyName string
Exchange string
Industry string
Website string
Description string
CEO string
Sector string
}
Company provides and interface for accessing company data parsed from IEX
type Stock ¶
type Stock struct {
Symbol string
CompanyName string
Exchange string `json:"primaryExchange"`
Sector string
Open float64
Close float64
High float64
Low float64
Volume int `json:"latestVolume"`
Price float64 `json:"latestPrice"`
Change float64
ChangePercent float64
AverageVolume int `json:"avgTotalVolume"`
MarketCap int
PeRatio float64
YearHigh float64 `json:"week52High"`
YearLow float64 `json:"week52Low"`
YtdChange float64
}
Stock provides an interface for accessing ticker data parsed from IEX
func (Stock) GetCompany ¶
GetCompany interpolates Company struct with JSON requests data from IEX
Click to show internal directories.
Click to hide internal directories.